// {{{RME classifier 'Logical View::VANT::VCTRL::VCONT::Aileron'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "Aileron.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <Aileron.h>

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"to_controller"
	  , &Aileron_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_Aileron_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new Aileron_Actor( _rts, _ref );
}

const RTActorClass Aileron =
{
	(const RTActorClass *)0
  , "Aileron"
  , (RTVersionId)0
  , 1
  , rtg_relays
  , new_Aileron_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
  , "Active"
};

#define SUPER RTActor

Aileron_Actor::Aileron_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
	, aileron_status( 1 )
{
}

Aileron_Actor::~Aileron_Actor( void )
{
}

int Aileron_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// to_controller
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &to_controller;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

// {{{RME transition ':TOP:Active:J4359E960009C:request_status'
INLINE_METHODS void Aileron_Actor::transition2_request_status( const void * rtdata, Aileron_Protocol::Conjugate * rtport )
{
	// {{{USR
	to_controller.aileron_status(aileron_status).send();
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359E97003A9:do_left'
INLINE_METHODS void Aileron_Actor::transition3_do_left( const void * rtdata, Aileron_Protocol::Conjugate * rtport )
{
	// {{{USR
	aileron_status = 0;
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359E9A00021:do_right'
INLINE_METHODS void Aileron_Actor::transition4_do_right( const void * rtdata, Aileron_Protocol::Conjugate * rtport )
{
	// {{{USR
	aileron_status=2;
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359E9E2013A:do_straight'
INLINE_METHODS void Aileron_Actor::transition5_do_straight( const void * rtdata, Aileron_Protocol::Conjugate * rtport )
{
	// {{{USR
	aileron_status=1;
	// }}}USR
}
// }}}RME

INLINE_CHAINS void Aileron_Actor::chain1_Initial( void )
{
	// transition ':TOP:Initial:Initial'
	rtgChainBegin( 1, "Initial" );
	rtgTransitionBegin();
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Aileron_Actor::chain2_request_status( void )
{
	// transition ':TOP:Active:J4359E960009C:request_status'
	rtgChainBegin( 2, "request_status" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition2_request_status( msg->data, (Aileron_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Aileron_Actor::chain4_do_right( void )
{
	// transition ':TOP:Active:J4359E9A00021:do_right'
	rtgChainBegin( 2, "do_right" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition4_do_right( msg->data, (Aileron_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Aileron_Actor::chain3_do_left( void )
{
	// transition ':TOP:Active:J4359E97003A9:do_left'
	rtgChainBegin( 2, "do_left" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition3_do_left( msg->data, (Aileron_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Aileron_Actor::chain5_do_straight( void )
{
	// transition ':TOP:Active:J4359E9E2013A:do_straight'
	rtgChainBegin( 2, "do_straight" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition5_do_straight( msg->data, (Aileron_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

void Aileron_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; stateIndex = rtg_parent_state[ stateIndex - 1 ] )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					chain1_Initial();
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		case 2:
			// {{{RME state ':TOP:Active'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 1:
				// {{{RME port 'to_controller'
				switch( signalIndex )
				{
				case Aileron_Protocol::Conjugate::rti_request_aileron_status:
					chain2_request_status();
					return;
				case Aileron_Protocol::Conjugate::rti_do_aileron_right:
					chain4_do_right();
					return;
				case Aileron_Protocol::Conjugate::rti_do_aileron_left:
					chain3_do_left();
					return;
				case Aileron_Protocol::Conjugate::rti_do_aileron_straight:
					chain5_do_straight();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * Aileron_Actor::getActorData( void ) const
{
	return &Aileron_Actor::rtg_class;
}

const RTActor_class Aileron_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 2
  , Aileron_Actor::rtg_parent_state
  , &Aileron
  , 0
  , (const RTComponentDescriptor *)0
  , 1
  , Aileron_Actor::rtg_ports
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 1
  , Aileron_Actor::rtg_Aileron_fields
};

const RTStateId Aileron_Actor::rtg_parent_state[] =
{
	0
  , 1
};

const RTPortDescriptor Aileron_Actor::rtg_ports[] =
{
	{
		"to_controller"
	  , (const char *)0
	  , &Aileron_Protocol::Conjugate::rt_class
	  , RTOffsetOf( Aileron_Actor, Aileron_Actor::to_controller )
	  , 1 // cardinality
	  , 1
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
};

const RTFieldDescriptor Aileron_Actor::rtg_Aileron_fields[] =
{
	// {{{RME classAttribute 'aileron_status'
	{
		"aileron_status"
	  , RTOffsetOf( Aileron_Actor, aileron_status )
		// {{{RME tool 'OT::CppTargetRTS' property 'TypeDescriptor'
	  , &RTType_int
		// }}}RME
		// {{{RME tool 'OT::CppTargetRTS' property 'GenerateTypeModifier'
	  , (const RTTypeModifier *)0
		// }}}RME
	}
	// }}}RME
};
#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
