// {{{RME classifier 'Logical View::VANT::VCNS::VCOM::COM_PROTOCOL'

#ifndef COM_PROTOCOL_H
#define COM_PROTOCOL_H

#ifdef PRAGMA
#pragma interface "COM_PROTOCOL.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <Coordinate.h>
#include <PMission.h>
#include <rgb.h>

struct COM_PROTOCOL
{
	class Base : public PMission::Base
	{
	public:
		inline Base( void );
		inline ~Base( void );
		enum
		{
			rti_request_fuel_level = rtiLast_PMission + 1
		  , rti_request_traj_data
		  , rti_request_positioning_value
		  , rti_request_speed_value
		  , rti_request_image_data
		  , rti_request_alarm_data
		  , rti_request_flight_data
		  , rti_mission_speed
		  , rti_mission_time
		  , rti_final_position
		};

	protected:
		enum { rtiLast_COM_PROTOCOL = rti_final_position };

	public:
		inline RTInSignal request_fuel_level( void );
		inline RTInSignal request_traj_data( void );
		inline RTInSignal request_positioning_value( void );
		inline RTInSignal request_speed_value( void );
		inline RTInSignal request_image_data( void );
		inline RTInSignal request_alarm_data( void );
		inline RTInSignal request_flight_data( void );
		inline RTInSignal mission_speed( void );
		inline RTInSignal mission_time( void );
		inline RTInSignal final_position( void );
		inline RTOutSignal fuel_level( const int & data );
		inline RTOutSignal speed_value( const int & data );
		inline RTOutSignal positioning_value( const RTTypedValue_Coordinate & data );
		inline RTOutSignal traj_data( const RTTypedValue_Coordinate & data );
		inline RTOutSignal image_data( const RTTypedValue_rgb & data );
		inline RTOutSignal alarm_data( const int & data );
		inline RTOutSignal flight_data( const int & data );
		inline RTOutSignal final_position( const RTTypedValue_Coordinate & data );
		inline RTOutSignal mission_speed( const int & data );
		inline RTOutSignal mission_time( const int & data );
		inline RTOutSignal toFlightControl( const char & data );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
	class Conjugate : public PMission::Conjugate
	{
	public:
		inline Conjugate( void );
		inline ~Conjugate( void );
		enum
		{
			rti_fuel_level = rtiLast_PMission + 1
		  , rti_speed_value
		  , rti_positioning_value
		  , rti_traj_data
		  , rti_image_data
		  , rti_alarm_data
		  , rti_flight_data
		  , rti_final_position
		  , rti_mission_speed
		  , rti_mission_time
		  , rti_toFlightControl
		};

	protected:
		enum { rtiLast_COM_PROTOCOL = rti_toFlightControl };

	public:
		inline RTInSignal fuel_level( void );
		inline RTInSignal speed_value( void );
		inline RTInSignal positioning_value( void );
		inline RTInSignal traj_data( void );
		inline RTInSignal image_data( void );
		inline RTInSignal alarm_data( void );
		inline RTInSignal flight_data( void );
		inline RTInSignal final_position( void );
		inline RTInSignal mission_speed( void );
		inline RTInSignal mission_time( void );
		inline RTInSignal toFlightControl( void );
		inline RTOutSignal request_fuel_level( const int & data );
		inline RTOutSignal request_traj_data( const int & data );
		inline RTOutSignal request_positioning_value( const RTTypedValue_Coordinate & data );
		inline RTOutSignal request_speed_value( const int & data );
		inline RTOutSignal request_image_data( const RTTypedValue_rgb & data );
		inline RTOutSignal request_alarm_data( const int & data );
		inline RTOutSignal request_flight_data( const int & data );
		inline RTOutSignal mission_speed( const int & data );
		inline RTOutSignal mission_time( const int & data );
		inline RTOutSignal final_position( const RTTypedValue_Coordinate & data );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
};

inline COM_PROTOCOL::Base::Base( void )
	: PMission::Base()
{
}

inline COM_PROTOCOL::Base::~Base( void )
{
}

inline RTInSignal COM_PROTOCOL::Base::request_fuel_level( void )
{
	return RTInSignal( this, rti_request_fuel_level );
}

inline RTInSignal COM_PROTOCOL::Base::request_traj_data( void )
{
	return RTInSignal( this, rti_request_traj_data );
}

inline RTInSignal COM_PROTOCOL::Base::request_positioning_value( void )
{
	return RTInSignal( this, rti_request_positioning_value );
}

inline RTInSignal COM_PROTOCOL::Base::request_speed_value( void )
{
	return RTInSignal( this, rti_request_speed_value );
}

inline RTInSignal COM_PROTOCOL::Base::request_image_data( void )
{
	return RTInSignal( this, rti_request_image_data );
}

inline RTInSignal COM_PROTOCOL::Base::request_alarm_data( void )
{
	return RTInSignal( this, rti_request_alarm_data );
}

inline RTInSignal COM_PROTOCOL::Base::request_flight_data( void )
{
	return RTInSignal( this, rti_request_flight_data );
}

inline RTInSignal COM_PROTOCOL::Base::mission_speed( void )
{
	return RTInSignal( this, rti_mission_speed );
}

inline RTInSignal COM_PROTOCOL::Base::mission_time( void )
{
	return RTInSignal( this, rti_mission_time );
}

inline RTInSignal COM_PROTOCOL::Base::final_position( void )
{
	return RTInSignal( this, rti_final_position );
}

inline RTOutSignal COM_PROTOCOL::Base::fuel_level( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_fuel_level, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::speed_value( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_speed_value, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::positioning_value( const RTTypedValue_Coordinate & data )
{
	return RTOutSignal( this, Conjugate::rti_positioning_value, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Base::traj_data( const RTTypedValue_Coordinate & data )
{
	return RTOutSignal( this, Conjugate::rti_traj_data, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Base::image_data( const RTTypedValue_rgb & data )
{
	return RTOutSignal( this, Conjugate::rti_image_data, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Base::alarm_data( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_alarm_data, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::flight_data( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_flight_data, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::final_position( const RTTypedValue_Coordinate & data )
{
	return RTOutSignal( this, Conjugate::rti_final_position, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Base::mission_speed( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_mission_speed, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::mission_time( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_mission_time, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Base::toFlightControl( const char & data )
{
	return RTOutSignal( this, Conjugate::rti_toFlightControl, &data, &RTType_char );
}

inline COM_PROTOCOL::Conjugate::Conjugate( void )
	: PMission::Conjugate()
{
}

inline COM_PROTOCOL::Conjugate::~Conjugate( void )
{
}

inline RTInSignal COM_PROTOCOL::Conjugate::fuel_level( void )
{
	return RTInSignal( this, rti_fuel_level );
}

inline RTInSignal COM_PROTOCOL::Conjugate::speed_value( void )
{
	return RTInSignal( this, rti_speed_value );
}

inline RTInSignal COM_PROTOCOL::Conjugate::positioning_value( void )
{
	return RTInSignal( this, rti_positioning_value );
}

inline RTInSignal COM_PROTOCOL::Conjugate::traj_data( void )
{
	return RTInSignal( this, rti_traj_data );
}

inline RTInSignal COM_PROTOCOL::Conjugate::image_data( void )
{
	return RTInSignal( this, rti_image_data );
}

inline RTInSignal COM_PROTOCOL::Conjugate::alarm_data( void )
{
	return RTInSignal( this, rti_alarm_data );
}

inline RTInSignal COM_PROTOCOL::Conjugate::flight_data( void )
{
	return RTInSignal( this, rti_flight_data );
}

inline RTInSignal COM_PROTOCOL::Conjugate::final_position( void )
{
	return RTInSignal( this, rti_final_position );
}

inline RTInSignal COM_PROTOCOL::Conjugate::mission_speed( void )
{
	return RTInSignal( this, rti_mission_speed );
}

inline RTInSignal COM_PROTOCOL::Conjugate::mission_time( void )
{
	return RTInSignal( this, rti_mission_time );
}

inline RTInSignal COM_PROTOCOL::Conjugate::toFlightControl( void )
{
	return RTInSignal( this, rti_toFlightControl );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_fuel_level( const int & data )
{
	return RTOutSignal( this, Base::rti_request_fuel_level, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_traj_data( const int & data )
{
	return RTOutSignal( this, Base::rti_request_traj_data, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_positioning_value( const RTTypedValue_Coordinate & data )
{
	return RTOutSignal( this, Base::rti_request_positioning_value, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_speed_value( const int & data )
{
	return RTOutSignal( this, Base::rti_request_speed_value, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_image_data( const RTTypedValue_rgb & data )
{
	return RTOutSignal( this, Base::rti_request_image_data, data.data, data.type );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_alarm_data( const int & data )
{
	return RTOutSignal( this, Base::rti_request_alarm_data, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::request_flight_data( const int & data )
{
	return RTOutSignal( this, Base::rti_request_flight_data, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::mission_speed( const int & data )
{
	return RTOutSignal( this, Base::rti_mission_speed, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::mission_time( const int & data )
{
	return RTOutSignal( this, Base::rti_mission_time, &data, &RTType_int );
}

inline RTOutSignal COM_PROTOCOL::Conjugate::final_position( const RTTypedValue_Coordinate & data )
{
	return RTOutSignal( this, Base::rti_final_position, data.data, data.type );
}

#endif /* COM_PROTOCOL_H */

// }}}RME
