// {{{RME classifier 'Logical View::VANT::VCTRL::VCONT::Elevator'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "Elevator.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <Elevator.h>

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"to_controller"
	  , &Elevator_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_Elevator_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new Elevator_Actor( _rts, _ref );
}

const RTActorClass Elevator =
{
	(const RTActorClass *)0
  , "Elevator"
  , (RTVersionId)0
  , 1
  , rtg_relays
  , new_Elevator_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
  , "Active"
};

#define SUPER RTActor

Elevator_Actor::Elevator_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
	, elevator_status( 1 )
{
}

Elevator_Actor::~Elevator_Actor( void )
{
}

int Elevator_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// to_controller
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &to_controller;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

// {{{RME transition ':TOP:Active:J4359EA40009E:request_elev'
INLINE_METHODS void Elevator_Actor::transition2_request_elev( const void * rtdata, Elevator_Protocol::Conjugate * rtport )
{
	// {{{USR
	to_controller.return_elevator_status(elevator_status).send();
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359EA9E0179:up'
INLINE_METHODS void Elevator_Actor::transition3_up( const void * rtdata, Elevator_Protocol::Conjugate * rtport )
{
	// {{{USR
	elevator_status = 2;
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359EAC200BD:down'
INLINE_METHODS void Elevator_Actor::transition4_down( const void * rtdata, Elevator_Protocol::Conjugate * rtport )
{
	// {{{USR
	elevator_status=0;
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:Active:J4359EADC034B:straight'
INLINE_METHODS void Elevator_Actor::transition5_straight( const void * rtdata, Elevator_Protocol::Conjugate * rtport )
{
	// {{{USR
	elevator_status = 1;
	// }}}USR
}
// }}}RME

INLINE_CHAINS void Elevator_Actor::chain1_Initial( void )
{
	// transition ':TOP:Initial:Initial'
	rtgChainBegin( 1, "Initial" );
	rtgTransitionBegin();
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Elevator_Actor::chain3_up( void )
{
	// transition ':TOP:Active:J4359EA9E0179:up'
	rtgChainBegin( 2, "up" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition3_up( msg->data, (Elevator_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Elevator_Actor::chain4_down( void )
{
	// transition ':TOP:Active:J4359EAC200BD:down'
	rtgChainBegin( 2, "down" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition4_down( msg->data, (Elevator_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Elevator_Actor::chain2_request_elev( void )
{
	// transition ':TOP:Active:J4359EA40009E:request_elev'
	rtgChainBegin( 2, "request_elev" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition2_request_elev( msg->data, (Elevator_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void Elevator_Actor::chain5_straight( void )
{
	// transition ':TOP:Active:J4359EADC034B:straight'
	rtgChainBegin( 2, "straight" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition5_straight( msg->data, (Elevator_Protocol::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

void Elevator_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; stateIndex = rtg_parent_state[ stateIndex - 1 ] )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					chain1_Initial();
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		case 2:
			// {{{RME state ':TOP:Active'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 1:
				// {{{RME port 'to_controller'
				switch( signalIndex )
				{
				case Elevator_Protocol::Conjugate::rti_do_elevator_up:
					chain3_up();
					return;
				case Elevator_Protocol::Conjugate::rti_do_elevator_down:
					chain4_down();
					return;
				case Elevator_Protocol::Conjugate::rti_request_elevator_status:
					chain2_request_elev();
					return;
				case Elevator_Protocol::Conjugate::rti_do_straight:
					chain5_straight();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * Elevator_Actor::getActorData( void ) const
{
	return &Elevator_Actor::rtg_class;
}

const RTActor_class Elevator_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 2
  , Elevator_Actor::rtg_parent_state
  , &Elevator
  , 0
  , (const RTComponentDescriptor *)0
  , 1
  , Elevator_Actor::rtg_ports
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 1
  , Elevator_Actor::rtg_Elevator_fields
};

const RTStateId Elevator_Actor::rtg_parent_state[] =
{
	0
  , 1
};

const RTPortDescriptor Elevator_Actor::rtg_ports[] =
{
	{
		"to_controller"
	  , (const char *)0
	  , &Elevator_Protocol::Conjugate::rt_class
	  , RTOffsetOf( Elevator_Actor, Elevator_Actor::to_controller )
	  , 1 // cardinality
	  , 1
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
};

const RTFieldDescriptor Elevator_Actor::rtg_Elevator_fields[] =
{
	// {{{RME classAttribute 'elevator_status'
	{
		"elevator_status"
	  , RTOffsetOf( Elevator_Actor, elevator_status )
		// {{{RME tool 'OT::CppTargetRTS' property 'TypeDescriptor'
	  , &RTType_int
		// }}}RME
		// {{{RME tool 'OT::CppTargetRTS' property 'GenerateTypeModifier'
	  , (const RTTypeModifier *)0
		// }}}RME
	}
	// }}}RME
};
#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
