// {{{RME classifier 'Logical View::VANT::VCTRL::VCOMB::Level_Protocol'

#ifndef Level_Protocol_H
#define Level_Protocol_H

#ifdef PRAGMA
#pragma interface "Level_Protocol.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>

struct Level_Protocol
{
	class Base : public RTRootProtocol
	{
	public:
		inline Base( void );
		inline ~Base( void );
		enum { rti_level_value = rtiLast_RTRootProtocol + 1 };

	protected:
		enum { rtiLast_Level_Protocol = rti_level_value };

	public:
		inline RTInSignal level_value( void );
		inline RTOutSignal request_fuel_level( void );
		inline RTOutSignal level_factor( const int & data );
		inline RTOutSignal engine_on( void );
		inline RTOutSignal unload( void );
		inline RTOutSignal engine_off( void );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
	class Conjugate : public RTRootProtocol
	{
	public:
		inline Conjugate( void );
		inline ~Conjugate( void );
		enum
		{
			rti_request_fuel_level = rtiLast_RTRootProtocol + 1
		  , rti_level_factor
		  , rti_engine_on
		  , rti_unload
		  , rti_engine_off
		};

	protected:
		enum { rtiLast_Level_Protocol = rti_engine_off };

	public:
		inline RTInSignal request_fuel_level( void );
		inline RTInSignal level_factor( void );
		inline RTInSignal engine_on( void );
		inline RTInSignal unload( void );
		inline RTInSignal engine_off( void );
		inline RTOutSignal level_value( const int & data );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
};

inline Level_Protocol::Base::Base( void )
	: RTRootProtocol()
{
}

inline Level_Protocol::Base::~Base( void )
{
}

inline RTInSignal Level_Protocol::Base::level_value( void )
{
	return RTInSignal( this, rti_level_value );
}

inline RTOutSignal Level_Protocol::Base::request_fuel_level( void )
{
	return RTOutSignal( this, Conjugate::rti_request_fuel_level, (const void *)0, &RTType_void );
}

inline RTOutSignal Level_Protocol::Base::level_factor( const int & data )
{
	return RTOutSignal( this, Conjugate::rti_level_factor, &data, &RTType_int );
}

inline RTOutSignal Level_Protocol::Base::engine_on( void )
{
	return RTOutSignal( this, Conjugate::rti_engine_on, (const void *)0, &RTType_void );
}

inline RTOutSignal Level_Protocol::Base::unload( void )
{
	return RTOutSignal( this, Conjugate::rti_unload, (const void *)0, &RTType_void );
}

inline RTOutSignal Level_Protocol::Base::engine_off( void )
{
	return RTOutSignal( this, Conjugate::rti_engine_off, (const void *)0, &RTType_void );
}

inline Level_Protocol::Conjugate::Conjugate( void )
	: RTRootProtocol()
{
}

inline Level_Protocol::Conjugate::~Conjugate( void )
{
}

inline RTInSignal Level_Protocol::Conjugate::request_fuel_level( void )
{
	return RTInSignal( this, rti_request_fuel_level );
}

inline RTInSignal Level_Protocol::Conjugate::level_factor( void )
{
	return RTInSignal( this, rti_level_factor );
}

inline RTInSignal Level_Protocol::Conjugate::engine_on( void )
{
	return RTInSignal( this, rti_engine_on );
}

inline RTInSignal Level_Protocol::Conjugate::unload( void )
{
	return RTInSignal( this, rti_unload );
}

inline RTInSignal Level_Protocol::Conjugate::engine_off( void )
{
	return RTInSignal( this, rti_engine_off );
}

inline RTOutSignal Level_Protocol::Conjugate::level_value( const int & data )
{
	return RTOutSignal( this, Base::rti_level_value, &data, &RTType_int );
}

#endif /* Level_Protocol_H */

// }}}RME
