// {{{RME classifier 'Logical View::VANT::VCTRL::VCONT::Power_Cont_Protocol'

#ifndef Power_Cont_Protocol_H
#define Power_Cont_Protocol_H

#ifdef PRAGMA
#pragma interface "Power_Cont_Protocol.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>

struct Power_Cont_Protocol
{
	class Base : public RTRootProtocol
	{
	public:
		inline Base( void );
		inline ~Base( void );
		enum
		{
			rti_do_engine_off = rtiLast_RTRootProtocol + 1
		  , rti_do_engine_on
		  , rti_request_full_power
		  , rti_increase_power
		  , rti_decrease_power
		  , rti_request_low_power
		};

	protected:
		enum { rtiLast_Power_Cont_Protocol = rti_request_low_power };

	public:
		inline RTInSignal do_engine_off( void );
		inline RTInSignal do_engine_on( void );
		inline RTInSignal request_full_power( void );
		inline RTInSignal increase_power( void );
		inline RTInSignal decrease_power( void );
		inline RTInSignal request_low_power( void );
		inline RTOutSignal engine_on( void );
		inline RTOutSignal engine_off( void );
		inline RTOutSignal full_power( void );
		inline RTOutSignal low_power( void );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
	class Conjugate : public RTRootProtocol
	{
	public:
		inline Conjugate( void );
		inline ~Conjugate( void );
		enum
		{
			rti_engine_on = rtiLast_RTRootProtocol + 1
		  , rti_engine_off
		  , rti_full_power
		  , rti_low_power
		};

	protected:
		enum { rtiLast_Power_Cont_Protocol = rti_low_power };

	public:
		inline RTInSignal engine_on( void );
		inline RTInSignal engine_off( void );
		inline RTInSignal full_power( void );
		inline RTInSignal low_power( void );
		inline RTOutSignal do_engine_off( void );
		inline RTOutSignal do_engine_on( void );
		inline RTOutSignal request_full_power( void );
		inline RTOutSignal increase_power( void );
		inline RTOutSignal decrease_power( void );
		inline RTOutSignal request_low_power( void );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
};

inline Power_Cont_Protocol::Base::Base( void )
	: RTRootProtocol()
{
}

inline Power_Cont_Protocol::Base::~Base( void )
{
}

inline RTInSignal Power_Cont_Protocol::Base::do_engine_off( void )
{
	return RTInSignal( this, rti_do_engine_off );
}

inline RTInSignal Power_Cont_Protocol::Base::do_engine_on( void )
{
	return RTInSignal( this, rti_do_engine_on );
}

inline RTInSignal Power_Cont_Protocol::Base::request_full_power( void )
{
	return RTInSignal( this, rti_request_full_power );
}

inline RTInSignal Power_Cont_Protocol::Base::increase_power( void )
{
	return RTInSignal( this, rti_increase_power );
}

inline RTInSignal Power_Cont_Protocol::Base::decrease_power( void )
{
	return RTInSignal( this, rti_decrease_power );
}

inline RTInSignal Power_Cont_Protocol::Base::request_low_power( void )
{
	return RTInSignal( this, rti_request_low_power );
}

inline RTOutSignal Power_Cont_Protocol::Base::engine_on( void )
{
	return RTOutSignal( this, Conjugate::rti_engine_on, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Base::engine_off( void )
{
	return RTOutSignal( this, Conjugate::rti_engine_off, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Base::full_power( void )
{
	return RTOutSignal( this, Conjugate::rti_full_power, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Base::low_power( void )
{
	return RTOutSignal( this, Conjugate::rti_low_power, (const void *)0, &RTType_void );
}

inline Power_Cont_Protocol::Conjugate::Conjugate( void )
	: RTRootProtocol()
{
}

inline Power_Cont_Protocol::Conjugate::~Conjugate( void )
{
}

inline RTInSignal Power_Cont_Protocol::Conjugate::engine_on( void )
{
	return RTInSignal( this, rti_engine_on );
}

inline RTInSignal Power_Cont_Protocol::Conjugate::engine_off( void )
{
	return RTInSignal( this, rti_engine_off );
}

inline RTInSignal Power_Cont_Protocol::Conjugate::full_power( void )
{
	return RTInSignal( this, rti_full_power );
}

inline RTInSignal Power_Cont_Protocol::Conjugate::low_power( void )
{
	return RTInSignal( this, rti_low_power );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::do_engine_off( void )
{
	return RTOutSignal( this, Base::rti_do_engine_off, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::do_engine_on( void )
{
	return RTOutSignal( this, Base::rti_do_engine_on, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::request_full_power( void )
{
	return RTOutSignal( this, Base::rti_request_full_power, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::increase_power( void )
{
	return RTOutSignal( this, Base::rti_increase_power, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::decrease_power( void )
{
	return RTOutSignal( this, Base::rti_decrease_power, (const void *)0, &RTType_void );
}

inline RTOutSignal Power_Cont_Protocol::Conjugate::request_low_power( void )
{
	return RTOutSignal( this, Base::rti_request_low_power, (const void *)0, &RTType_void );
}

#endif /* Power_Cont_Protocol_H */

// }}}RME
