// {{{RME classifier 'Logical View::VANT::VCTRL::VCONT::Rudder_Protocol'

#ifndef Rudder_Protocol_H
#define Rudder_Protocol_H

#ifdef PRAGMA
#pragma interface "Rudder_Protocol.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>

struct Rudder_Protocol
{
	class Base : public RTRootProtocol
	{
	public:
		inline Base( void );
		inline ~Base( void );
		enum { rti_rudder_status = rtiLast_RTRootProtocol + 1 };

	protected:
		enum { rtiLast_Rudder_Protocol = rti_rudder_status };

	public:
		inline RTInSignal rudder_status( void );
		inline RTOutSignal request_rudder_status( void );
		inline RTOutSignal do_rudder_left( void );
		inline RTOutSignal do_rudder_right( void );
		inline RTOutSignal do_rudder_straight( void );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
	class Conjugate : public RTRootProtocol
	{
	public:
		inline Conjugate( void );
		inline ~Conjugate( void );
		enum
		{
			rti_request_rudder_status = rtiLast_RTRootProtocol + 1
		  , rti_do_rudder_left
		  , rti_do_rudder_right
		  , rti_do_rudder_straight
		};

	protected:
		enum { rtiLast_Rudder_Protocol = rti_do_rudder_straight };

	public:
		inline RTInSignal request_rudder_status( void );
		inline RTInSignal do_rudder_left( void );
		inline RTInSignal do_rudder_right( void );
		inline RTInSignal do_rudder_straight( void );
		inline RTOutSignal rudder_status( const int & data );
		static const RTProtocolDescriptor rt_class;

	private:
		static const RTSignalDescriptor rt_signals[];
	};
};

inline Rudder_Protocol::Base::Base( void )
	: RTRootProtocol()
{
}

inline Rudder_Protocol::Base::~Base( void )
{
}

inline RTInSignal Rudder_Protocol::Base::rudder_status( void )
{
	return RTInSignal( this, rti_rudder_status );
}

inline RTOutSignal Rudder_Protocol::Base::request_rudder_status( void )
{
	return RTOutSignal( this, Conjugate::rti_request_rudder_status, (const void *)0, &RTType_void );
}

inline RTOutSignal Rudder_Protocol::Base::do_rudder_left( void )
{
	return RTOutSignal( this, Conjugate::rti_do_rudder_left, (const void *)0, &RTType_void );
}

inline RTOutSignal Rudder_Protocol::Base::do_rudder_right( void )
{
	return RTOutSignal( this, Conjugate::rti_do_rudder_right, (const void *)0, &RTType_void );
}

inline RTOutSignal Rudder_Protocol::Base::do_rudder_straight( void )
{
	return RTOutSignal( this, Conjugate::rti_do_rudder_straight, (const void *)0, &RTType_void );
}

inline Rudder_Protocol::Conjugate::Conjugate( void )
	: RTRootProtocol()
{
}

inline Rudder_Protocol::Conjugate::~Conjugate( void )
{
}

inline RTInSignal Rudder_Protocol::Conjugate::request_rudder_status( void )
{
	return RTInSignal( this, rti_request_rudder_status );
}

inline RTInSignal Rudder_Protocol::Conjugate::do_rudder_left( void )
{
	return RTInSignal( this, rti_do_rudder_left );
}

inline RTInSignal Rudder_Protocol::Conjugate::do_rudder_right( void )
{
	return RTInSignal( this, rti_do_rudder_right );
}

inline RTInSignal Rudder_Protocol::Conjugate::do_rudder_straight( void )
{
	return RTInSignal( this, rti_do_rudder_straight );
}

inline RTOutSignal Rudder_Protocol::Conjugate::rudder_status( const int & data )
{
	return RTOutSignal( this, Base::rti_rudder_status, &data, &RTType_int );
}

#endif /* Rudder_Protocol_H */

// }}}RME
