// {{{RME classifier 'Logical View::VANT::VANT'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "VANT.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <VANT.h>
#include <Bus_Comb_Protocol.h>
#include <Bus_Cont_Protocol.h>
#include <Bus_Power_Protocol.h>
#include <COM_PROTOCOL.h>
#include <NAV_PROTOCOL.h>
#include <VIG_PROTOCOL.h>
extern const RTActorClass VCNS_Top;
extern const RTActorClass VCTRL_Top;
extern const RTActorClass VSUP_Top;

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"com_to_station"
	  , &COM_PROTOCOL::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_VANT_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new VANT_Actor( _rts, _ref );
}

const RTActorClass VANT =
{
	(const RTActorClass *)0
  , "VANT"
  , (RTVersionId)0
  , 1
  , rtg_relays
  , new_VANT_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
};

static const RTInterfaceDescriptor rtg_interfaces_vsupTop[] =
{
	{
		"bus_power_sup"
	  , 1
	}
  , {
		"bus_cont_sup"
	  , 1
	}
  , {
		"bus_comb_sup"
	  , 1
	}
  , {
		"nav_sup"
	  , 1
	}
  , {
		"vig_sup"
	  , 1
	}
  , {
		"com_sup"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vsupTop[] =
{
	{
		0
	  , &Bus_Power_Protocol::Base::rt_class
	}
  , {
		1
	  , &Bus_Cont_Protocol::Conjugate::rt_class
	}
  , {
		2
	  , &Bus_Comb_Protocol::Conjugate::rt_class
	}
  , {
		3
	  , &NAV_PROTOCOL::Conjugate::rt_class
	}
  , {
		4
	  , &VIG_PROTOCOL::Conjugate::rt_class
	}
  , {
		5
	  , &COM_PROTOCOL::Base::rt_class
	}
};

static const RTInterfaceDescriptor rtg_interfaces_vcnsTop[] =
{
	{
		"vig_to_bus"
	  , 1
	}
  , {
		"com_to_bus"
	  , 1
	}
  , {
		"com_to_station"
	  , 1
	}
  , {
		"com_to_sat"
	  , 0
	}
  , {
		"nav_to_bus"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vcnsTop[] =
{
	{
		0
	  , &VIG_PROTOCOL::Base::rt_class
	}
  , {
		1
	  , &COM_PROTOCOL::Conjugate::rt_class
	}
  , {
		2
	  , &COM_PROTOCOL::Base::rt_class
	}
  , {
		4
	  , &NAV_PROTOCOL::Base::rt_class
	}
};

static const RTInterfaceDescriptor rtg_interfaces_vctrlTop[] =
{
	{
		"bus_power"
	  , 1
	}
  , {
		"bus_comb"
	  , 1
	}
  , {
		"bus_cont"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vctrlTop[] =
{
	{
		0
	  , &Bus_Power_Protocol::Conjugate::rt_class
	}
  , {
		1
	  , &Bus_Comb_Protocol::Base::rt_class
	}
  , {
		2
	  , &Bus_Cont_Protocol::Base::rt_class
	}
};

#define SUPER RTActor

VANT_Actor::VANT_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
{
}

VANT_Actor::~VANT_Actor( void )
{
}

int VANT_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// com_to_station
		if( rtg_repIndex < 1 )
		{
			// vcnsTop/com_to_station
			return vcnsTop._followIn( rtg_end, 2, rtg_repIndex );
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

int VANT_Actor::_followOutV( RTBindingEnd & rtg_end, int rtg_compId, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_compId )
	{
	case 1:
		// vsupTop
		switch( rtg_portId )
		{
		case 0:
			// bus_power_sup
			if( rtg_repIndex < 1 )
			{
				// vctrlTop/bus_power
				return vctrlTop._followIn( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 1:
			// bus_cont_sup
			if( rtg_repIndex < 1 )
			{
				// vctrlTop/bus_cont
				return vctrlTop._followIn( rtg_end, 2, rtg_repIndex );
			}
			break;
		case 2:
			// bus_comb_sup
			if( rtg_repIndex < 1 )
			{
				// vctrlTop/bus_comb
				return vctrlTop._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		case 3:
			// nav_sup
			if( rtg_repIndex < 1 )
			{
				// vcnsTop/nav_to_bus
				return vcnsTop._followIn( rtg_end, 4, rtg_repIndex );
			}
			break;
		case 4:
			// vig_sup
			if( rtg_repIndex < 1 )
			{
				// vcnsTop/vig_to_bus
				return vcnsTop._followIn( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 5:
			// com_sup
			if( rtg_repIndex < 1 )
			{
				// vcnsTop/com_to_bus
				return vcnsTop._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	case 2:
		// vcnsTop
		switch( rtg_portId )
		{
		case 0:
			// vig_to_bus
			if( rtg_repIndex < 1 )
			{
				// vsupTop/vig_sup
				return vsupTop._followIn( rtg_end, 4, rtg_repIndex );
			}
			break;
		case 1:
			// com_to_bus
			if( rtg_repIndex < 1 )
			{
				// vsupTop/com_sup
				return vsupTop._followIn( rtg_end, 5, rtg_repIndex );
			}
			break;
		case 2:
			// com_to_station
			if( rtg_repIndex < 1 )
			{
				// com_to_station
				return _followOut( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 4:
			// nav_to_bus
			if( rtg_repIndex < 1 )
			{
				// vsupTop/nav_sup
				return vsupTop._followIn( rtg_end, 3, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	case 3:
		// vctrlTop
		switch( rtg_portId )
		{
		case 0:
			// bus_power
			if( rtg_repIndex < 1 )
			{
				// vsupTop/bus_power_sup
				return vsupTop._followIn( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 1:
			// bus_comb
			if( rtg_repIndex < 1 )
			{
				// vsupTop/bus_comb_sup
				return vsupTop._followIn( rtg_end, 2, rtg_repIndex );
			}
			break;
		case 2:
			// bus_cont
			if( rtg_repIndex < 1 )
			{
				// vsupTop/bus_cont_sup
				return vsupTop._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	default:
		break;
	}
	return RTActor::_followOutV( rtg_end, rtg_compId, rtg_portId, rtg_repIndex );
}

void VANT_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * VANT_Actor::getActorData( void ) const
{
	return &VANT_Actor::rtg_class;
}

const RTActor_class VANT_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 1
  , VANT_Actor::rtg_parent_state
  , &VANT
  , 3
  , VANT_Actor::rtg_capsule_roles
  , 0
  , (const RTPortDescriptor *)0
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 0
  , (const RTFieldDescriptor *)0
};

const RTStateId VANT_Actor::rtg_parent_state[] =
{
	0
};

const RTComponentDescriptor VANT_Actor::rtg_capsule_roles[] =
{
	{
		"vsupTop"
	  , &VSUP_Top
	  , RTOffsetOf( VANT_Actor, vsupTop )
	  , 1
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 6
	  , rtg_interfaces_vsupTop
	  , 6
	  , rtg_bindings_vsupTop
	}
  , {
		"vcnsTop"
	  , &VCNS_Top
	  , RTOffsetOf( VANT_Actor, vcnsTop )
	  , 2
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 5
	  , rtg_interfaces_vcnsTop
	  , 4
	  , rtg_bindings_vcnsTop
	}
  , {
		"vctrlTop"
	  , &VCTRL_Top
	  , RTOffsetOf( VANT_Actor, vctrlTop )
	  , 3
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 3
	  , rtg_interfaces_vctrlTop
	  , 3
	  , rtg_bindings_vctrlTop
	}
};

#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
