// {{{RME classifier 'Logical View::VANT::VSUP::VBAD::VBAD_Interface'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "VBAD_Interface.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <VBAD_Interface.h>
#include <MissionVant.h>

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"interface_mi"
	  , &VBAD_PInterface::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"interface_status"
	  , &VBAD_PInterface::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"interface_rw"
	  , &VBAD_PInterface::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"vbad_vcal"
	  , &vcal_protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"vbad_vcxp"
	  , &vcxp_protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"vbad_vsel"
	  , &vsel_protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_power_control"
	  , &Bus_Power_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_cont_sup"
	  , &Bus_Cont_Protocol::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_comb_sup"
	  , &Bus_Comb_Protocol::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"nav_sup"
	  , &NAV_PROTOCOL::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"vig_sup"
	  , &VIG_PROTOCOL::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"com_sup"
	  , &COM_PROTOCOL::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_VBAD_Interface_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new VBAD_Interface_Actor( _rts, _ref );
}

const RTActorClass VBAD_Interface =
{
	(const RTActorClass *)0
  , "VBAD_Interface"
  , (RTVersionId)0
  , 12
  , rtg_relays
  , new_VBAD_Interface_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
  , "InternalEntrance"
  , "MI"
  , "STA"
  , "RW"
};

#define SUPER RTActor

VBAD_Interface_Actor::VBAD_Interface_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
{
}

VBAD_Interface_Actor::~VBAD_Interface_Actor( void )
{
}

// {{{RME operation 'Kernel()'
void VBAD_Interface_Actor::Kernel( void )
{
	// {{{USR
	// verificar qual sinal esta chegando para 
	// poder detectar o destino
	void *myData = getMsg()->getData();
	char *mySignal = (char*)getMsg()->getSignalName();

	// escrever no barramento
	interface_rw.activeWrite((char)myData).send();

	// recebendo WayPoints da NAVEGAO (hoje est de COMUNICAO)
	// direcionando para o CONTROLE DE VO
	if(mySignal=="sendMission")
	{

		// instanciar a classe
		MissionVant* myMission; 
		myMission = ((MissionVant*) getMsg()->getData()); 

		// enviar a misso
		bus_cont_sup.sendMission(*myMission).send();

		//bus_cont_sup.destination_value((int)myData).send();
		//bus_cont_sup.position_value((int)myData).send();
		printf("MSG_I: Message was sent to VCTRL-FlightControl\n");

	}

	// recebendo sinal de ok do controle do vant
	// disparar misso de reconhecimento/ataque
	if(mySignal=="doAction"){
		
		// instanciar a classe
		MissionVant* myMission; 
		myMission = ((MissionVant*) getMsg()->getData()); 

		// mandar para vigilncia
		vig_sup.sendMission(*myMission).send();
		
		// comando passada para vigilancia
		printf("MSG_I: Command was sent to VCNS...\n");
		
	}

	if(mySignal=="valuepower")
	{
		printf("MSG_I: Redirecting to RW (WRITE) ...\n");
	}
	else
		printf("MSG_I: This signal isn't know (%s) at the moment ...\n", mySignal);

	// }}}USR
}
// }}}RME

int VBAD_Interface_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// interface_mi
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &interface_mi;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 1:
		// interface_status
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &interface_status;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 2:
		// interface_rw
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &interface_rw;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 3:
		// vbad_vcal
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &vbad_vcal;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 4:
		// vbad_vcxp
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &vbad_vcxp;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 5:
		// vbad_vsel
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &vbad_vsel;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 6:
		// bus_power_control
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &bus_power_control;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 7:
		// bus_cont_sup
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &bus_cont_sup;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 8:
		// bus_comb_sup
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &bus_comb_sup;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 9:
		// nav_sup
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &nav_sup;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 10:
		// vig_sup
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &vig_sup;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	case 11:
		// com_sup
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &com_sup;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

// {{{RME transition ':TOP:Initial:Initial'
INLINE_METHODS void VBAD_Interface_Actor::transition1_Initial( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	printf("\n\n\n*** DATA BUS ACTIVATED *** \n\n");
	printf("MSG_I: Now listening... \n");
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:InternalEntrance:J434BCABD0178:t_monitora_interrupt'
INLINE_METHODS void VBAD_Interface_Actor::transition2_t_monitora_interrupt( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	printf("MSG_I: Redirecting to Interruption Monitor ...\n");
	interface_mi.activeMI().send();
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:MI:J434E9C490242:t_return_minterrupt'
INLINE_METHODS void VBAD_Interface_Actor::transition3_t_return_minterrupt( const void * rtdata, VBAD_PInterface::Base * rtport )
{
	// {{{USR
	printf("\nMSG_I: Now listening again...\n");
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:InternalEntrance:J434FCC03039A:t_monitora_status'
INLINE_METHODS void VBAD_Interface_Actor::transition4_t_monitora_status( const void * rtdata, VBAD_PInterface::Conjugate * rtport )
{
	// {{{USR
	printf("MSG_I: Redirecting to Status Monitor ...\n");

	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:STA:J434FCCCD0204:t_return_status'
INLINE_METHODS void VBAD_Interface_Actor::transition5_t_return_status( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	printf("\nMSG_I: Now listening again...\n");
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:InternalEntrance:J434FCD3A03AA:t_monitora_r'
INLINE_METHODS void VBAD_Interface_Actor::transition6_t_monitora_r( const char * rtdata, vbad_inheritance::Conjugate * rtport )
{
	// {{{USR
	printf("MSG_I: Redirecting to RW (READ) ...\n");
	interface_rw.activeRead('0').send();
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:RW:J434FCDDF002E:t_return_rw'
INLINE_METHODS void VBAD_Interface_Actor::transition7_t_return_rw( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	printf("\nMSG_I: Now listening again...\n");
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:InternalEntrance:J434FD5B1039A:t_monitora_w'
INLINE_METHODS void VBAD_Interface_Actor::transition8_t_monitora_w( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	// verificao de origem dos sinais e 
	// encaminha para seu destino correto
	Kernel();
	// }}}USR
}
// }}}RME

INLINE_CHAINS void VBAD_Interface_Actor::chain1_Initial( void )
{
	// transition ':TOP:Initial:Initial'
	rtgChainBegin( 1, "Initial" );
	rtgTransitionBegin();
	transition1_Initial( msg->data, msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void VBAD_Interface_Actor::chain4_t_monitora_status( void )
{
	// transition ':TOP:InternalEntrance:J434FCC03039A:t_monitora_status'
	rtgChainBegin( 2, "t_monitora_status" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition4_t_monitora_status( msg->data, (VBAD_PInterface::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 4 );
}

INLINE_CHAINS void VBAD_Interface_Actor::chain6_t_monitora_r( void )
{
	// transition ':TOP:InternalEntrance:J434FCD3A03AA:t_monitora_r'
	rtgChainBegin( 2, "t_monitora_r" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition6_t_monitora_r( (const char *)msg->data, (vbad_inheritance::Conjugate *)msg->sap() );
	rtgTransitionEnd();
	enterState( 5 );
}

INLINE_CHAINS void VBAD_Interface_Actor::chain8_t_monitora_w( void )
{
	// transition ':TOP:InternalEntrance:J434FD5B1039A:t_monitora_w'
	rtgChainBegin( 2, "t_monitora_w" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition8_t_monitora_w( msg->data, msg->sap() );
	rtgTransitionEnd();
	enterState( 5 );
}

INLINE_CHAINS void VBAD_Interface_Actor::chain3_t_return_minterrupt( void )
{
	// transition ':TOP:MI:J434E9C490242:t_return_minterrupt'
	rtgChainBegin( 3, "t_return_minterrupt" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition3_t_return_minterrupt( msg->data, (VBAD_PInterface::Base *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void VBAD_Interface_Actor::chain7_t_return_rw( void )
{
	// transition ':TOP:RW:J434FCDDF002E:t_return_rw'
	rtgChainBegin( 5, "t_return_rw" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition7_t_return_rw( msg->data, msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

void VBAD_Interface_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; stateIndex = rtg_parent_state[ stateIndex - 1 ] )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					chain1_Initial();
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		case 2:
			// {{{RME state ':TOP:InternalEntrance'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 2:
				// {{{RME port 'interface_status'
				switch( signalIndex )
				{
				case VBAD_PInterface::Conjugate::rti_activeSTA:
					chain4_t_monitora_status();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 4:
				// {{{RME port 'vbad_vcal'
				switch( signalIndex )
				{
				case vcal_protocol::Conjugate::rti_read:
					chain6_t_monitora_r();
					return;
				case vcal_protocol::Conjugate::rti_write:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 5:
				// {{{RME port 'vbad_vcxp'
				switch( signalIndex )
				{
				case vcxp_protocol::Conjugate::rti_read:
					chain6_t_monitora_r();
					return;
				case vcxp_protocol::Conjugate::rti_write:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 6:
				// {{{RME port 'vbad_vsel'
				switch( signalIndex )
				{
				case vsel_protocol::Conjugate::rti_read:
					chain6_t_monitora_r();
					return;
				case vsel_protocol::Conjugate::rti_write:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 7:
				// {{{RME port 'bus_power_control'
				switch( signalIndex )
				{
				case Bus_Power_Protocol::Conjugate::rti_value_power:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 8:
				// {{{RME port 'bus_cont_sup'
				switch( signalIndex )
				{
				case Bus_Cont_Protocol::Base::rti_doAction:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 12:
				// {{{RME port 'com_sup'
				switch( signalIndex )
				{
				case COM_PROTOCOL::Conjugate::rti_sendMission:
					chain8_t_monitora_w();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		case 3:
			// {{{RME state ':TOP:MI'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 1:
				// {{{RME port 'interface_mi'
				switch( signalIndex )
				{
				case VBAD_PInterface::Base::rti_returnContext:
					chain3_t_return_minterrupt();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		case 4:
			// {{{RME state ':TOP:STA'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			break;
			// }}}RME
		case 5:
			// {{{RME state ':TOP:RW'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 3:
				// {{{RME port 'interface_rw'
				switch( signalIndex )
				{
				case VBAD_PInterface::Base::rti_returnContext:
					chain7_t_return_rw();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			case 7:
				// {{{RME port 'bus_power_control'
				switch( signalIndex )
				{
				case Bus_Power_Protocol::Conjugate::rti_value_power:
					chain7_t_return_rw();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * VBAD_Interface_Actor::getActorData( void ) const
{
	return &VBAD_Interface_Actor::rtg_class;
}

const RTActor_class VBAD_Interface_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 5
  , VBAD_Interface_Actor::rtg_parent_state
  , &VBAD_Interface
  , 0
  , (const RTComponentDescriptor *)0
  , 12
  , VBAD_Interface_Actor::rtg_ports
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 0
  , (const RTFieldDescriptor *)0
};

const RTStateId VBAD_Interface_Actor::rtg_parent_state[] =
{
	0
  , 1
  , 1
  , 1
  , 1
};

const RTPortDescriptor VBAD_Interface_Actor::rtg_ports[] =
{
	{
		"interface_mi"
	  , (const char *)0
	  , &VBAD_PInterface::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::interface_mi )
	  , 1 // cardinality
	  , 1
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"interface_status"
	  , (const char *)0
	  , &VBAD_PInterface::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::interface_status )
	  , 1 // cardinality
	  , 2
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"interface_rw"
	  , (const char *)0
	  , &VBAD_PInterface::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::interface_rw )
	  , 1 // cardinality
	  , 3
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"vbad_vcal"
	  , (const char *)0
	  , &vcal_protocol::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::vbad_vcal )
	  , 1 // cardinality
	  , 4
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"vbad_vcxp"
	  , (const char *)0
	  , &vcxp_protocol::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::vbad_vcxp )
	  , 1 // cardinality
	  , 5
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"vbad_vsel"
	  , (const char *)0
	  , &vsel_protocol::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::vbad_vsel )
	  , 1 // cardinality
	  , 6
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"bus_power_control"
	  , (const char *)0
	  , &Bus_Power_Protocol::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::bus_power_control )
	  , 1 // cardinality
	  , 7
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"bus_cont_sup"
	  , (const char *)0
	  , &Bus_Cont_Protocol::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::bus_cont_sup )
	  , 1 // cardinality
	  , 8
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"bus_comb_sup"
	  , (const char *)0
	  , &Bus_Comb_Protocol::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::bus_comb_sup )
	  , 1 // cardinality
	  , 9
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"nav_sup"
	  , (const char *)0
	  , &NAV_PROTOCOL::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::nav_sup )
	  , 1 // cardinality
	  , 10
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"vig_sup"
	  , (const char *)0
	  , &VIG_PROTOCOL::Base::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::vig_sup )
	  , 1 // cardinality
	  , 11
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
  , {
		"com_sup"
	  , (const char *)0
	  , &COM_PROTOCOL::Conjugate::rt_class
	  , RTOffsetOf( VBAD_Interface_Actor, VBAD_Interface_Actor::com_sup )
	  , 1 // cardinality
	  , 12
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
};

#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
