// {{{RME classifier 'Logical View::VANT::VCTRL::VCTRL_Main'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "VCTRL_Main.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <VCTRL_Main.h>
#include <Bus_Comb_Protocol.h>
#include <Bus_Cont_Protocol.h>
#include <Bus_Power_Protocol.h>
#include <Power_Comb_Protocol.h>
#include <Power_Cont_Protocol.h>
extern const RTActorClass VCOMB;
extern const RTActorClass VCONT;
extern const RTActorClass VPOTE;

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"bus_power"
	  , &Bus_Power_Protocol::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_comb"
	  , &Bus_Comb_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_cont"
	  , &Bus_Cont_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_VCTRL_Main_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new VCTRL_Main_Actor( _rts, _ref );
}

const RTActorClass VCTRL_Main =
{
	(const RTActorClass *)0
  , "VCTRL_Main"
  , (RTVersionId)0
  , 3
  , rtg_relays
  , new_VCTRL_Main_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
};

static const RTInterfaceDescriptor rtg_interfaces_vcomb[] =
{
	{
		"bus_port"
	  , 1
	}
  , {
		"power_port"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vcomb[] =
{
	{
		0
	  , &Bus_Comb_Protocol::Base::rt_class
	}
  , {
		1
	  , &Power_Comb_Protocol::Base::rt_class
	}
};

static const RTInterfaceDescriptor rtg_interfaces_vcont[] =
{
	{
		"bus_port"
	  , 1
	}
  , {
		"power_port"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vcont[] =
{
	{
		0
	  , &Bus_Cont_Protocol::Base::rt_class
	}
  , {
		1
	  , &Power_Cont_Protocol::Base::rt_class
	}
};

static const RTInterfaceDescriptor rtg_interfaces_vpote[] =
{
	{
		"bus_port"
	  , 1
	}
  , {
		"flygth_port"
	  , 1
	}
  , {
		"fuelcontrol_port"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vpote[] =
{
	{
		0
	  , &Bus_Power_Protocol::Conjugate::rt_class
	}
  , {
		1
	  , &Power_Cont_Protocol::Conjugate::rt_class
	}
  , {
		2
	  , &Power_Comb_Protocol::Conjugate::rt_class
	}
};

#define SUPER RTActor

VCTRL_Main_Actor::VCTRL_Main_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
{
}

VCTRL_Main_Actor::~VCTRL_Main_Actor( void )
{
}

int VCTRL_Main_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// bus_power
		if( rtg_repIndex < 1 )
		{
			// vpote/bus_port
			return vpote._followIn( rtg_end, 0, rtg_repIndex );
		}
		break;
	case 1:
		// bus_comb
		if( rtg_repIndex < 1 )
		{
			// vcomb/bus_port
			return vcomb._followIn( rtg_end, 0, rtg_repIndex );
		}
		break;
	case 2:
		// bus_cont
		if( rtg_repIndex < 1 )
		{
			// vcont/bus_port
			return vcont._followIn( rtg_end, 0, rtg_repIndex );
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

int VCTRL_Main_Actor::_followOutV( RTBindingEnd & rtg_end, int rtg_compId, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_compId )
	{
	case 1:
		// vcomb
		switch( rtg_portId )
		{
		case 0:
			// bus_port
			if( rtg_repIndex < 1 )
			{
				// bus_comb
				return _followOut( rtg_end, 1, rtg_repIndex );
			}
			break;
		case 1:
			// power_port
			if( rtg_repIndex < 1 )
			{
				// vpote/fuelcontrol_port
				return vpote._followIn( rtg_end, 2, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	case 2:
		// vcont
		switch( rtg_portId )
		{
		case 0:
			// bus_port
			if( rtg_repIndex < 1 )
			{
				// bus_cont
				return _followOut( rtg_end, 2, rtg_repIndex );
			}
			break;
		case 1:
			// power_port
			if( rtg_repIndex < 1 )
			{
				// vpote/flygth_port
				return vpote._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	case 3:
		// vpote
		switch( rtg_portId )
		{
		case 0:
			// bus_port
			if( rtg_repIndex < 1 )
			{
				// bus_power
				return _followOut( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 1:
			// flygth_port
			if( rtg_repIndex < 1 )
			{
				// vcont/power_port
				return vcont._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		case 2:
			// fuelcontrol_port
			if( rtg_repIndex < 1 )
			{
				// vcomb/power_port
				return vcomb._followIn( rtg_end, 1, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	default:
		break;
	}
	return RTActor::_followOutV( rtg_end, rtg_compId, rtg_portId, rtg_repIndex );
}

void VCTRL_Main_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * VCTRL_Main_Actor::getActorData( void ) const
{
	return &VCTRL_Main_Actor::rtg_class;
}

const RTActor_class VCTRL_Main_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 1
  , VCTRL_Main_Actor::rtg_parent_state
  , &VCTRL_Main
  , 3
  , VCTRL_Main_Actor::rtg_capsule_roles
  , 0
  , (const RTPortDescriptor *)0
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 0
  , (const RTFieldDescriptor *)0
};

const RTStateId VCTRL_Main_Actor::rtg_parent_state[] =
{
	0
};

const RTComponentDescriptor VCTRL_Main_Actor::rtg_capsule_roles[] =
{
	{
		"vcomb"
	  , &VCOMB
	  , RTOffsetOf( VCTRL_Main_Actor, vcomb )
	  , 1
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 2
	  , rtg_interfaces_vcomb
	  , 2
	  , rtg_bindings_vcomb
	}
  , {
		"vcont"
	  , &VCONT
	  , RTOffsetOf( VCTRL_Main_Actor, vcont )
	  , 2
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 2
	  , rtg_interfaces_vcont
	  , 2
	  , rtg_bindings_vcont
	}
  , {
		"vpote"
	  , &VPOTE
	  , RTOffsetOf( VCTRL_Main_Actor, vpote )
	  , 3
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 3
	  , rtg_interfaces_vpote
	  , 3
	  , rtg_bindings_vpote
	}
};

#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
