// {{{RME classifier 'Logical View::VANT::VSUP::VSEL::VSEL_PowerControl'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "VSEL_PowerControl.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <VSEL_PowerControl.h>

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"vsel_internal"
	  , &vsel_protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_VSEL_PowerControl_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new VSEL_PowerControl_Actor( _rts, _ref );
}

const RTActorClass VSEL_PowerControl =
{
	(const RTActorClass *)0
  , "VSEL_PowerControl"
  , (RTVersionId)0
  , 1
  , rtg_relays
  , new_VSEL_PowerControl_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
  , "consumer"
};

#define SUPER RTActor

VSEL_PowerControl_Actor::VSEL_PowerControl_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
	, intInterval( // intervalo de 30 para consumo de bateria
99 )
{
}

VSEL_PowerControl_Actor::~VSEL_PowerControl_Actor( void )
{
}

// {{{RME operation 'Consumer()'
void VSEL_PowerControl_Actor::Consumer( void )
{
	// {{{USR
	intBatteryCarga-=5;
	// }}}USR
}
// }}}RME

int VSEL_PowerControl_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// vsel_internal
		if( rtg_repIndex < 1 )
		{
			rtg_end.port = &vsel_internal;
			rtg_end.index = rtg_repIndex;
			return 1;
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

// {{{RME transition ':TOP:Initial:Initial'
INLINE_METHODS void VSEL_PowerControl_Actor::transition1_Initial( const void * rtdata, RTProtocol * rtport )
{
	// {{{USR
	// disparar o timer a cada tantos seg 
	// para consumir energia
	timer.informIn(RTTimespec(intInterval,0));
	// }}}USR
}
// }}}RME

// {{{RME transition ':TOP:consumer:J4357DB08013A:life'
INLINE_METHODS void VSEL_PowerControl_Actor::transition2_life( const void * rtdata, Timing::Base * rtport )
{
	// {{{USR
	// disparar o timer a cada tantos seg 
	// para consumir energia
	timer.informIn(RTTimespec(intInterval,0));

	// rodar o processo consumidor de energia
	Consumer();

	// informar a carga
	vsel_internal.informCarga(intBatteryCarga).send();
	// }}}USR
}
// }}}RME

INLINE_CHAINS void VSEL_PowerControl_Actor::chain1_Initial( void )
{
	// transition ':TOP:Initial:Initial'
	rtgChainBegin( 1, "Initial" );
	rtgTransitionBegin();
	transition1_Initial( msg->data, msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

INLINE_CHAINS void VSEL_PowerControl_Actor::chain2_life( void )
{
	// transition ':TOP:consumer:J4357DB08013A:life'
	rtgChainBegin( 2, "life" );
	exitState( rtg_parent_state );
	rtgTransitionBegin();
	transition2_life( msg->data, (Timing::Base *)msg->sap() );
	rtgTransitionEnd();
	enterState( 2 );
}

void VSEL_PowerControl_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; stateIndex = rtg_parent_state[ stateIndex - 1 ] )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					chain1_Initial();
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		case 2:
			// {{{RME state ':TOP:consumer'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			case 1:
				// {{{RME port 'timer'
				switch( signalIndex )
				{
				case Timing::Base::rti_timeout:
					chain2_life();
					return;
				default:
					break;
				}
				break;
				// }}}RME
			default:
				break;
			}
			break;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * VSEL_PowerControl_Actor::getActorData( void ) const
{
	return &VSEL_PowerControl_Actor::rtg_class;
}

const RTActor_class VSEL_PowerControl_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 2
  , VSEL_PowerControl_Actor::rtg_parent_state
  , &VSEL_PowerControl
  , 0
  , (const RTComponentDescriptor *)0
  , 2
  , VSEL_PowerControl_Actor::rtg_ports
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 1
  , VSEL_PowerControl_Actor::rtg_VSEL_PowerControl_fields
};

const RTStateId VSEL_PowerControl_Actor::rtg_parent_state[] =
{
	0
  , 1
};

const RTPortDescriptor VSEL_PowerControl_Actor::rtg_ports[] =
{
	{
		"timer"
	  , (const char *)0
	  , &Timing::Base::rt_class
	  , RTOffsetOf( VSEL_PowerControl_Actor, VSEL_PowerControl_Actor::timer )
	  , 1 // cardinality
	  , 1
	  , RTPortDescriptor::KindSpecial + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityProtected
	}
  , {
		"vsel_internal"
	  , (const char *)0
	  , &vsel_protocol::Conjugate::rt_class
	  , RTOffsetOf( VSEL_PowerControl_Actor, VSEL_PowerControl_Actor::vsel_internal )
	  , 1 // cardinality
	  , 2
	  , RTPortDescriptor::KindWired + RTPortDescriptor::NotificationDisabled + RTPortDescriptor::RegisterNotPermitted + RTPortDescriptor::VisibilityPublic
	}
};

const RTFieldDescriptor VSEL_PowerControl_Actor::rtg_VSEL_PowerControl_fields[] =
{
	// {{{RME classAttribute 'intInterval'
	{
		"intInterval"
	  , RTOffsetOf( VSEL_PowerControl_Actor, intInterval )
		// {{{RME tool 'OT::CppTargetRTS' property 'TypeDescriptor'
	  , &RTType_int
		// }}}RME
		// {{{RME tool 'OT::CppTargetRTS' property 'GenerateTypeModifier'
	  , (const RTTypeModifier *)0
		// }}}RME
	}
	// }}}RME
};
#undef SUPER

// {{{RME classAttribute 'intBatteryCarga'
int intBatteryCarga( 100 );
// }}}RME

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
