// {{{RME classifier 'Logical View::VANT::VSUP::VSUP_Top'

#if defined( PRAGMA ) && ! defined( PRAGMA_IMPLEMENTED )
#pragma implementation "VSUP_Top.h"
#endif

#include <RTSystem/VANT_EC_SAT.h>
#include <VSUP_Top.h>
#include <Bus_Comb_Protocol.h>
#include <Bus_Cont_Protocol.h>
#include <Bus_Power_Protocol.h>
#include <COM_PROTOCOL.h>
#include <NAV_PROTOCOL.h>
#include <VIG_PROTOCOL.h>
extern const RTActorClass VSUP_CSC;

// {{{RME tool 'OT::Cpp' property 'ImplementationPreface'
// {{{USR

// }}}USR
// }}}RME

static const RTRelayDescriptor rtg_relays[] =
{
	{
		"bus_power_sup"
	  , &Bus_Power_Protocol::Conjugate::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_cont_sup"
	  , &Bus_Cont_Protocol::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"bus_comb_sup"
	  , &Bus_Comb_Protocol::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"nav_sup"
	  , &NAV_PROTOCOL::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"vig_sup"
	  , &VIG_PROTOCOL::Base::rt_class
	  , 1 // cardinality
	}
  , {
		"com_sup"
	  , &COM_PROTOCOL::Conjugate::rt_class
	  , 1 // cardinality
	}
};

static RTActor * new_VSUP_Top_Actor( RTController * _rts, RTActorRef * _ref )
{
	return new VSUP_Top_Actor( _rts, _ref );
}

const RTActorClass VSUP_Top =
{
	(const RTActorClass *)0
  , "VSUP_Top"
  , (RTVersionId)0
  , 6
  , rtg_relays
  , new_VSUP_Top_Actor
};

static const char * const rtg_state_names[] =
{
	"TOP"
};

static const RTInterfaceDescriptor rtg_interfaces_vsup[] =
{
	{
		"bus_power_sup"
	  , 1
	}
  , {
		"bus_comb_sup"
	  , 1
	}
  , {
		"bus_cont_sup"
	  , 1
	}
  , {
		"com_sup"
	  , 1
	}
  , {
		"vig_sup"
	  , 1
	}
  , {
		"nav_sup"
	  , 1
	}
};

static const RTBindingDescriptor rtg_bindings_vsup[] =
{
	{
		0
	  , &Bus_Power_Protocol::Base::rt_class
	}
  , {
		1
	  , &Bus_Comb_Protocol::Conjugate::rt_class
	}
  , {
		2
	  , &Bus_Cont_Protocol::Conjugate::rt_class
	}
  , {
		3
	  , &COM_PROTOCOL::Base::rt_class
	}
  , {
		4
	  , &VIG_PROTOCOL::Conjugate::rt_class
	}
  , {
		5
	  , &NAV_PROTOCOL::Conjugate::rt_class
	}
};

#define SUPER RTActor

VSUP_Top_Actor::VSUP_Top_Actor( RTController * rtg_rts, RTActorRef * rtg_ref )
	: RTActor( rtg_rts, rtg_ref )
{
}

VSUP_Top_Actor::~VSUP_Top_Actor( void )
{
}

int VSUP_Top_Actor::_followInV( RTBindingEnd & rtg_end, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_portId )
	{
	case 0:
		// bus_power_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/bus_power_sup
			return vsup._followIn( rtg_end, 0, rtg_repIndex );
		}
		break;
	case 1:
		// bus_cont_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/bus_cont_sup
			return vsup._followIn( rtg_end, 2, rtg_repIndex );
		}
		break;
	case 2:
		// bus_comb_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/bus_comb_sup
			return vsup._followIn( rtg_end, 1, rtg_repIndex );
		}
		break;
	case 3:
		// nav_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/nav_sup
			return vsup._followIn( rtg_end, 5, rtg_repIndex );
		}
		break;
	case 4:
		// vig_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/vig_sup
			return vsup._followIn( rtg_end, 4, rtg_repIndex );
		}
		break;
	case 5:
		// com_sup
		if( rtg_repIndex < 1 )
		{
			// vsup/com_sup
			return vsup._followIn( rtg_end, 3, rtg_repIndex );
		}
		break;
	default:
		break;
	}
	return RTActor::_followInV( rtg_end, rtg_portId, rtg_repIndex );
}

int VSUP_Top_Actor::_followOutV( RTBindingEnd & rtg_end, int rtg_compId, int rtg_portId, int rtg_repIndex )
{
	switch( rtg_compId )
	{
	case 1:
		// vsup
		switch( rtg_portId )
		{
		case 0:
			// bus_power_sup
			if( rtg_repIndex < 1 )
			{
				// bus_power_sup
				return _followOut( rtg_end, 0, rtg_repIndex );
			}
			break;
		case 1:
			// bus_comb_sup
			if( rtg_repIndex < 1 )
			{
				// bus_comb_sup
				return _followOut( rtg_end, 2, rtg_repIndex );
			}
			break;
		case 2:
			// bus_cont_sup
			if( rtg_repIndex < 1 )
			{
				// bus_cont_sup
				return _followOut( rtg_end, 1, rtg_repIndex );
			}
			break;
		case 3:
			// com_sup
			if( rtg_repIndex < 1 )
			{
				// com_sup
				return _followOut( rtg_end, 5, rtg_repIndex );
			}
			break;
		case 4:
			// vig_sup
			if( rtg_repIndex < 1 )
			{
				// vig_sup
				return _followOut( rtg_end, 4, rtg_repIndex );
			}
			break;
		case 5:
			// nav_sup
			if( rtg_repIndex < 1 )
			{
				// nav_sup
				return _followOut( rtg_end, 3, rtg_repIndex );
			}
			break;
		default:
			break;
		}
	default:
		break;
	}
	return RTActor::_followOutV( rtg_end, rtg_compId, rtg_portId, rtg_repIndex );
}

void VSUP_Top_Actor::rtsBehavior( int signalIndex, int portIndex )
{
	for( int stateIndex = getCurrentState(); ; )
		switch( stateIndex )
		{
		case 1:
			// {{{RME state ':TOP'
			switch( portIndex )
			{
			case 0:
				switch( signalIndex )
				{
				case 1:
					return;
				default:
					break;
				}
				break;
			default:
				break;
			}
			unexpectedMessage();
			return;
			// }}}RME
		default:
			unexpectedState();
			return;
		}
}

const RTActor_class * VSUP_Top_Actor::getActorData( void ) const
{
	return &VSUP_Top_Actor::rtg_class;
}

const RTActor_class VSUP_Top_Actor::rtg_class =
{
	(const RTActor_class *)0
  , rtg_state_names
  , 1
  , VSUP_Top_Actor::rtg_parent_state
  , &VSUP_Top
  , 1
  , VSUP_Top_Actor::rtg_capsule_roles
  , 0
  , (const RTPortDescriptor *)0
  , 0
  , (const RTLocalBindingDescriptor *)0
  , 0
  , (const RTFieldDescriptor *)0
};

const RTStateId VSUP_Top_Actor::rtg_parent_state[] =
{
	0
};

const RTComponentDescriptor VSUP_Top_Actor::rtg_capsule_roles[] =
{
	{
		"vsup"
	  , &VSUP_CSC
	  , RTOffsetOf( VSUP_Top_Actor, vsup )
	  , 1
	  , RTComponentDescriptor::Fixed
	  , 1
	  , 1 // cardinality
	  , 6
	  , rtg_interfaces_vsup
	  , 6
	  , rtg_bindings_vsup
	}
};

#undef SUPER

// {{{RME tool 'OT::Cpp' property 'ImplementationEnding'
// {{{USR

// }}}USR
// }}}RME

// }}}RME
